`EXAMPLE` and `DATA` variables

A simple example of what the input data might look like, and the slightly more complex `DATA` variable provided in the starter code.

    In [ ]: EXAMPLE = [{'name': 'Two', 'order': 2}, {'name': 'One', 'order': 1}]

    In [ ]: DATA = [{'name': 'A', 'order': 3},
     {'name': 'B', 'order': 2},
     {'name': 'C', 'order': 3},
     {'name': 'D', 'order': 1},
     {'name': 'E', 'order': 4}]